Changelog
=========

0.0.4 (2025-02-05)
------------------

- added missing typing hint imports
- added ability to extend color lists and palettes with custom ones
- added `palette_list_to_triplets` method to convert flat list into list of R,G,B tuples
- added `palettes` method for returning the sorted list of available palettes


0.0.3 (2025-02-04)
------------------

- exposed `color_lists` method


0.0.2 (2025-02-04)
------------------

- added methods `parse_rgb` and `parse_rgba`
- added class `ColorProvider` to make color management easier


0.0.1 (2025-02-03)
------------------

- initial release
